@@ -20,3 +20,6 @@ def cal():
     while True:
         z = eval(input('Put your math problem here: '))
         print(z)
+def ral(your_list):
+  a = random.choice(your_list)
+  print(a)
